==> agrosyst-web-0.11-sources.jar: fr/inra/agrosyst/web/actions/practiced/LoadPracticedPerennialCroppingPlanSpeciesJson.java <==
package fr.inra.agrosyst.web.actions.practiced;

/*
 * #%L
 * Agrosyst :: Web
 * $Id: LoadPracticedPerennialCroppingPlanSpeciesJson.java 3161 2014-02-10 09:29:12Z athimel $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-0.11/agrosyst-web/src/main/java/fr/inra/agrosyst/web/actions/practiced/LoadPracticedPerennialCroppingPlanSpeciesJson.java $
 * %%
 * Copyright (C) 2013 - 2014 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import java.util.List;

import fr.inra.agrosyst.api.services.practiced.PracticedCropCycleSpeciesDto;
import fr.inra.agrosyst.api.services.practiced.PracticedSystemService;
import fr.inra.agrosyst.web.actions.AbstractJsonAction;

/**
 * Chargement des espèces d'une culture si vraiment l'utilisateur change la culture d'un
 * cycle de cultures pérennes.
 * 
 * @author cosse
 */
public class LoadPracticedPerennialCroppingPlanSpeciesJson extends AbstractJsonAction {

    private static final long serialVersionUID = 4680946995049096766L;

    protected transient PracticedSystemService practicedSystemService;

    protected String croppingPlanEntryCode;

    protected String campaigns;

    protected List<PracticedCropCycleSpeciesDto> cropCyclePerennialSpeciesDtos;

    public void setPracticedSystemService(PracticedSystemService practicedSystemService) {
        this.practicedSystemService = practicedSystemService;
    }

    public void setCampaigns(String campaigns) {
        this.campaigns = campaigns;
    }

    public void setCroppingPlanEntryCode(String croppingPlanEntryCode) {
        this.croppingPlanEntryCode = croppingPlanEntryCode;
    }

    @Override
    public String execute() throws Exception {
        cropCyclePerennialSpeciesDtos = practicedSystemService.getCropCyclePerennialSpecies(croppingPlanEntryCode, null, campaigns);
        return SUCCESS;
    }

    @Override
    public Object getJsonData() {
        return cropCyclePerennialSpeciesDtos;
    }
}

==> agrosyst-web-1.0.3-sources.jar: fr/inra/agrosyst/web/actions/practiced/LoadPracticedPerennialCroppingPlanSpeciesJson.java <==
package fr.inra.agrosyst.web.actions.practiced;

/*
 * #%L
 * Agrosyst :: Web
 * $Id: LoadPracticedPerennialCroppingPlanSpeciesJson.java 3161 2014-02-10 09:29:12Z athimel $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.0.3/agrosyst-web/src/main/java/fr/inra/agrosyst/web/actions/practiced/LoadPracticedPerennialCroppingPlanSpeciesJson.java $
 * %%
 * Copyright (C) 2013 - 2014 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import java.util.List;

import fr.inra.agrosyst.api.services.practiced.PracticedCropCycleSpeciesDto;
import fr.inra.agrosyst.api.services.practiced.PracticedSystemService;
import fr.inra.agrosyst.web.actions.AbstractJsonAction;

/**
 * Chargement des espèces d'une culture si vraiment l'utilisateur change la culture d'un
 * cycle de cultures pérennes.
 * 
 * @author cosse
 */
public class LoadPracticedPerennialCroppingPlanSpeciesJson extends AbstractJsonAction {

    private static final long serialVersionUID = 4680946995049096766L;

    protected transient PracticedSystemService practicedSystemService;

    protected String croppingPlanEntryCode;

    protected String campaigns;

    protected List<PracticedCropCycleSpeciesDto> cropCyclePerennialSpeciesDtos;

    public void setPracticedSystemService(PracticedSystemService practicedSystemService) {
        this.practicedSystemService = practicedSystemService;
    }

    public void setCampaigns(String campaigns) {
        this.campaigns = campaigns;
    }

    public void setCroppingPlanEntryCode(String croppingPlanEntryCode) {
        this.croppingPlanEntryCode = croppingPlanEntryCode;
    }

    @Override
    public String execute() throws Exception {
        cropCyclePerennialSpeciesDtos = practicedSystemService.getCropCyclePerennialSpecies(croppingPlanEntryCode, null, campaigns);
        return SUCCESS;
    }

    @Override
    public Object getJsonData() {
        return cropCyclePerennialSpeciesDtos;
    }
}
